@@ -59,16 +59,16 @@ public:
      * \param handleQuitSignals flag if signals SIGINT, SIGTERM, SIGHUP should be handled internaly (\sa quit() application)
      */
     Application(int &argc, char **argv, bool handleQuitSignals);
-    virtual ~Application() {}
+    ~Application() override {}
     /*! Install UNIX signal handler for signals defined in \param signalList
      * Upon receiving of any of this signals the \sa unixSignal signal is emitted
      */
     void listenToUnixSignals(QList<int> const & signolList);
 
-private slots:
+private Q_SLOTS:
     void updateTheme();
 
-signals:
+Q_SIGNALS:
     void themeChanged();
     /*! Signal is emitted upon receival of registered unix signal
      * \param signo the received unix signal number
